#[repr(u8)]pub enum RotationAxis {
Left = 0,
Centeredvertical = 1,
Leftandright = 2,
Right = 3,
Top = 4,
Centeredhorizontal = 5,
Topandbottom = 6,
Bottom = 7,
Leftbarrier = 8,
Leftandrightbarriers = 9,
Rightbarrier = 10,
}Variants
Left = 0
The panel rotates around a vertical axis located on the left side of the panel
Centeredvertical = 1
The panel rotates around a vertical axis located in the center of the panel
Leftandright = 2
The panels rotates around vertical axes located on the left and right sides of the panel
Right = 3
The panel rotates around a vertical axis located on the right side of the panel
Top = 4
The panel rotates around a horizontal axis located on the top of the panel
Centeredhorizontal = 5
The panel rotates around a horizontal axis located in the center of the panel
Topandbottom = 6
The panels rotates around horizontal axes located on the top and bottom of the panel
Bottom = 7
The panel rotates around a horizontal axis located on the bottom of the panel
Leftbarrier = 8
The barrier tilts around an axis located at the left end of the barrier
Leftandrightbarriers = 9
The dual barriers tilt around axes located at each side of the composite barrier
Rightbarrier = 10
The barrier tilts around an axis located at the right end of the barrier
Implementations